@@ -24,6 +24,15 @@
  * Copyright 1990 Sun Microsystems, Inc. All rights reserved.
  * Use is subject to license terms.
  */
+/*
+ * This file contains modifications Copyright 2006-2007 J. Schilling
+ *
+ * @(#)error.c	1.3 06/12/29 J. Schilling
+ */
+#if defined(sun) || defined(__GNUC__)
+
+#ident "@(#)error.c 1.3 06/12/29 J. Schilling"
+#endif
 /*
  * @(#)error.c 1.2 06/12/12
  */
