@@ -24,6 +24,15 @@
  * Copyright 1994 Sun Microsystems, Inc. All rights reserved.
  * Use is subject to license terms.
  */
+/*
+ * This file contains modifications Copyright 2006-2007 J. Schilling
+ *
+ * @(#)del_ba.c	1.3 07/01/11 J. Schilling
+ */
+#if defined(sun) || defined(__GNUC__)
+
+#ident "@(#)del_ba.c 1.3 07/01/11 J. Schilling"
+#endif
 /*
  * @(#)del_ba.c 1.3 06/12/12
  */
@@ -39,7 +48,6 @@ register struct deltab *dt;
 char *str;
 {
 	register char *p;
-/*	char *sid_ba(), *date_ba();*/
 
 	p = str;
 	*p++ = CTLCHAR;
