@@ -24,6 +24,15 @@
  * Copyright 1998 Sun Microsystems, Inc. All rights reserved.
  * Use is subject to license terms.
  */
+/*
+ * This file contains modifications Copyright 2006-2007 J. Schilling
+ *
+ * @(#)fmterr.c	1.3 07/01/11 J. Schilling
+ */
+#if defined(sun) || defined(__GNUC__)
+
+#ident "@(#)fmterr.c 1.3 07/01/11 J. Schilling"
+#endif
 /*
  * @(#)fmterr.c 1.5 06/12/12
  */
