@@ -24,6 +24,15 @@
  * Copyright 1994 Sun Microsystems, Inc. All rights reserved.
  * Use is subject to license terms.
  */
+/*
+ * This file contains modifications Copyright 2006-2007 J. Schilling
+ *
+ * @(#)newstats.c	1.3 07/01/11 J. Schilling
+ */
+#if defined(sun) || defined(__GNUC__)
+
+#ident "@(#)newstats.c 1.3 07/01/11 J. Schilling"
+#endif
 /*
  * @(#)newstats.c 1.3 06/12/12
  */
@@ -41,7 +50,6 @@ register char *ch;
 	char fivech[6];
 	register char *r;
 	int i;
-/*	void	putline();*/
 
 	r = fivech;
 	for (i=0; i < 5; i++)
