@@ -24,6 +24,15 @@
  * Copyright 2002 Sun Microsystems, Inc. All rights reserved.
  * Use is subject to license terms.
  */
+/*
+ * This file contains modifications Copyright 2006-2007 J. Schilling
+ *
+ * @(#)permiss.c	1.4 07/01/20 J. Schilling
+ */
+#if defined(sun) || defined(__GNUC__)
+
+#ident "@(#)permiss.c 1.4 07/01/20 J. Schilling"
+#endif
 /*
  * @(#)permiss.c 1.9 06/12/12
  */
@@ -100,7 +109,6 @@ void
 permiss(pkt)
 register struct packet *pkt;
 {
-	extern char *Sflags[];
 	register char *p;
 	register int n;
 	extern char SccsError[];
