@@ -24,6 +24,15 @@
  * Copyright 2002 Sun Microsystems, Inc. All rights reserved.
  * Use is subject to license terms.
  */
+/*
+ * This file contains modifications Copyright 2006-2007 J. Schilling
+ *
+ * @(#)putline.c	1.3 07/01/11 J. Schilling
+ */
+#if defined(sun) || defined(__GNUC__)
+
+#ident "@(#)putline.c 1.3 07/01/11 J. Schilling"
+#endif
 /*
  * @(#)putline.c 1.13 06/12/12
  */
@@ -187,7 +196,7 @@ register struct stats *stats;
 		xmsg(xf, NOGETTEXT("flushline"));
 	if (fclose(Xiop) == EOF)
 		xmsg(xf, NOGETTEXT("flushline"));
-	Xiop = 0;
+	Xiop = NULL;
 }
 
 void
