@@ -24,6 +24,15 @@
  * Copyright 1990 Sun Microsystems, Inc. All rights reserved.
  * Use is subject to license terms.
  */
+/*
+ * This file contains modifications Copyright 2006-2007 J. Schilling
+ *
+ * @(#)ccstypes.h	1.3 07/01/09 J. Schilling
+ */
+#if defined(sun) || defined(__GNUC__)
+
+#ident "@(#)ccstypes.h 1.3 07/01/09 J. Schilling"
+#endif
 /*
  * @(#)ccstypes.h 1.2 06/12/12
  */
