@@ -21,7 +21,15 @@
  */
 /*	Copyright (c) 1988 AT&T	*/
 /*	  All Rights Reserved  	*/
+/*
+ * This file contains modifications Copyright 2006-2007 J. Schilling
+ *
+ * @(#)macros.h	1.3 07/01/09 J. Schilling
+ */
+#if defined(sun) || defined(__GNUC__)
 
+#ident "@(#)macros.h 1.3 07/01/09 J. Schilling"
+#endif
 
 #ifndef	_MACROS_H
 #define	_MACROS_H
